.. image:: https://readthedocs.org/projects/cnvrg_experiment_chart/badge/?version=latest
    :alt: ReadTheDocs
    :target: https://cnvrg_experiment_chart.readthedocs.io/en/stable/
.. image:: https://img.shields.io/coveralls/github/nctiggy/cnvrg_experiment_chart/main.svg
    :alt: Coveralls
    :target: https://coveralls.io/r/nctiggy/cnvrg_experiment_chart
.. image:: https://img.shields.io/pypi/v/cnvrg_experiment_chart.svg
    :alt: PyPI-Server
    :target: https://pypi.org/project/cnvrg_experiment_chart/
.. image:: https://static.pepy.tech/personalized-badge/cnvrg-experiment-chart?period=total&units=international_system&left_color=red&right_color=black&left_text=Downloads
    :alt: Monthly Downloads
    :target: https://pepy.tech/project/cnvrg_experiment_chart
.. image:: https://img.shields.io/badge/-PyScaffold-005CA0?logo=pyscaffold
    :alt: Project generated with PyScaffold
    :target: https://pyscaffold.org/

|

======================
cnvrg_experiment_chart
======================


    This is a helper library to make using cnvrg charts a more intuitive
    process. Currently line charts are the only supported kinds.


.. _pyscaffold-notes:

Note
====

This project has been set up using PyScaffold 4.5. For details and usage
information on PyScaffold see https://pyscaffold.org/.
